@@ -1,3 +1,5 @@
+#!/usr/bin/env python
+
 """
 gather_profile_stats.py /path/to/dir/of/profiles
 
@@ -6,8 +8,9 @@ hotshot.stats (the formats are incompatible)
 """
 
 from hotshot import stats
+import os
 import pstats
-import sys, os
+import sys
 
 def gather_stats(p):
     profiles = {}
@@ -22,7 +25,7 @@ def gather_stats(p):
         else:
             continue
         print "Processing %s" % f
-        if profiles.has_key(path):
+        if path in profiles:
             profiles[path].add(prof)
         else:
             profiles[path] = prof
