@@ -99,9 +99,24 @@ class TimesinceTests(unittest.TestCase):
         self.assertEqual(timesince(now_tz), u'0 minutes')
         self.assertEqual(timeuntil(now_tz, now_tz_i), u'0 minutes')
 
+    def test_date_objects(self):
+        """ Both timesince and timeuntil should work on date objects (#17937). """
+        today = datetime.date.today()
+        self.assertEqual(timesince(today + self.oneday), u'0 minutes')
+        self.assertEqual(timeuntil(today - self.oneday), u'0 minutes')
+
     def test_both_date_objects(self):
         """ Timesince should work with both date objects (#9672) """
         today = datetime.date.today()
-        self.assertEqual(timeuntil(today+self.oneday, today), u'1 day')
-        self.assertEqual(timeuntil(today-self.oneday, today), u'0 minutes')
-        self.assertEqual(timeuntil(today+self.oneweek, today), u'1 week')
+        self.assertEqual(timeuntil(today + self.oneday, today), u'1 day')
+        self.assertEqual(timeuntil(today - self.oneday, today), u'0 minutes')
+        self.assertEqual(timeuntil(today + self.oneweek, today), u'1 week')
+
+    def test_naive_datetime_with_tzinfo_attribute(self):
+        class naive(datetime.tzinfo):
+            def utcoffset(self, dt):
+                return None
+        future = datetime.datetime(2080, 1, 1, tzinfo=naive())
+        self.assertEqual(timesince(future), u'0 minutes')
+        past = datetime.datetime(1980, 1, 1, tzinfo=naive())
+        self.assertEqual(timeuntil(past), u'0 minutes')
